# pygong

A simple public library for Python program development.

# Usage

## Compile & Install

Ensure that wheel/twine is the latest version.

runnning build.bat/build.sh.

```shell

python -m build

pip install xxx.whl
```

## Direct installation

```shell
pip install pygong
```

# License

Apache 2.0

# Refer

https://packaging.python.org/en/latest/tutorials/packaging-projects/
https://daobook.github.io/flit/pyproject_toml.html
https://packaging.python.org/en/latest/guides/writing-pyproject-toml/